@@ -38,7 +38,6 @@
 #include <QtDBus/QtDBus>
 #include "common/ukuisettings.h"
 #include "iukuipanel.h"
-#include "popupmenu.h"
 #include "ukuipanelglobals.h"
 #include "highlight-effect.h"
 
@@ -84,8 +83,7 @@ class UKUI_PANEL_API UKUIPanel : public QFrame, public IUKUIPanel
 
     Q_PROPERTY(QString position READ qssPosition)
 
-    Q_CLASSINFO("D-Bus Interface", "com.ukui.panel.settings")
-
+    Q_CLASSINFO("D-Bus Interface", "org.ukui.panel.settings")
     // for configuration dialog
     friend class ConfigPanelWidget;
     friend class ConfigPluginsWidget;
@@ -150,6 +148,12 @@ public:
     // IUKUIPanel overrides ........
     IUKUIPanel::Position position() const override { return mPosition; }
     QRect globalGeometry() const override;
+    /**
+     * @brief calculatePopupWindowPos 计算任务栏弹窗的位置
+     * @param absolutePos
+     * @param windowSize 窗口尺寸
+     * @return
+     */
     QRect calculatePopupWindowPos(QPoint const & absolutePos, QSize const & windowSize) const override;
     QRect calculatePopupWindowPos(const IUKUIPanelPlugin *plugin, const QSize &windowSize) const override;
     void willShowWindow(QWidget * w) override;
@@ -213,11 +217,15 @@ public:
      * \sa positionToStr()
      */
     static IUKUIPanel::Position strToPosition(const QString &str, IUKUIPanel::Position defaultValue);
+    static IUKUIPanel::Position intToPosition(const int p, IUKUIPanel::Position defaultValue);
+
 
     // Settings
     int iconSize() const override { return mIconSize; } //!< Implement IUKUIPanel::iconSize().
     int lineCount() const override { return mLineCount; } //!< Implement IUKUIPanel::lineCount().
     int panelSize() const override{ return mPanelSize; }
+    int sizeModel() const override{ return (mPanelSize == SML_SIZE_PANEL_IN_CALC ? 0 : (mPanelSize == MID_SIZE_PANEL_IN_CALC ? 1 : 2)); }
+    bool isMaxSize() const override{ return mPanelSize == MAX_SIZE_PANEL_IN_CALC; }
     int length() const { return mLength; }
     bool lengthInPercents() const { return mLengthInPercents; }
     UKUIPanel::Alignment alignment() const { return mAlignment; }
@@ -246,7 +254,7 @@ public:
      * \brief Updates the config dialog. Used for updating its icons
      * when the panel-specific icon theme changes.
      */
-    void updateConfigDialog() const;
+//    void updateConfigDialog() const;
 
 public slots:
     /**
@@ -308,14 +316,12 @@ public slots:
     void setAlignment(UKUIPanel::Alignment value, bool save); //!< \sa setPanelSize()
     void setFontColor(QColor color, bool save); //!< \sa setPanelSize()
     void setBackgroundColor(QColor color, bool save); //!< \sa setPanelSize()
-    void setOpacity(int opacity, bool save); //!< \sa setPanelSize()
     void setReserveSpace(bool reserveSpace, bool save); //!< \sa setPanelSize()
     void setHidable(bool hidable, bool save); //!< \sa setPanelSize()
     void setVisibleMargin(bool visibleMargin, bool save); //!< \sa setPanelSize()
     void setAnimationTime(int animationTime, bool save); //!< \sa setPanelSize()
     void setShowDelay(int showDelay, bool save); //!< \sa setPanelSize()
     void setIconTheme(const QString& iconTheme);
-    void setPanelBackground(bool effective);
 
     /**
      * @brief Saves the current configuration, i.e. writes the current
@@ -390,7 +396,7 @@ protected:
      * @param event The QShowEvent sent by Qt.
      */
     void showEvent(QShowEvent *event) override;
-//    void paintEvent(QPaintEvent *);
+    void paintEvent(QPaintEvent *);
 
 public slots:
     /**
@@ -407,7 +413,7 @@ public slots:
      * by UKUIPanelApplication). That is why this method/slot has to be
      * public.
      */
-    void showConfigDialog();
+//    void showConfigDialog();
 
 private slots:
     /**
@@ -419,7 +425,7 @@ private slots:
      * be connected to this slot so this method gets called whenever the
      * user clicks that button.
      */
-    void showAddPluginDialog();
+//    void showAddPluginDialog();
     /**
      * @brief Recalculates the geometry of the panel and reserves the
      * window manager strut, i.e. it calls setPanelGeometry() and
@@ -455,6 +461,7 @@ private slots:
     void userRequestForDeletion();
 
 private:
+    int scale;
     /**
      * @brief The UKUIPanelLayout of this panel. All the Plugins will be added
      * to the UI via this layout.
@@ -547,6 +554,7 @@ private:
      *
      * \sa panelSize(), setPanelSize().
      */
+    void styleAdjust();
     int mPanelSize;
     /**
      * @brief Stores the edge length of the panel icons in pixels.
@@ -682,7 +690,7 @@ private:
      * @brief Pointer to the current ConfigPanelDialog if there is any. Make
      * sure to test this pointer for validity because it is lazily loaded.
      */
-   QPointer<ConfigPanelDialog> mConfigDialog;
+//   QPointer<ConfigPanelDialog> mConfigDialog;
     //ConfigPanelDialog  *mConfigDialog;
     //QPointer<ConfigPanelWidget> mConfigWidget;
 
@@ -695,33 +703,44 @@ private:
      * @brief Flag for providing the configuration options in panel's context menu
      */
     bool mLockPanel;
-
-    /**
-     * @brief Updates the style sheet for the panel. First, the stylesheet is
-     * created from the preferences. Then, it is set via
-     * QWidget::setStyleSheet().
-     */
-    void updateStyleSheet();
+    double transparency;
 
     // settings should be kept private for security
     UKUi::Settings *settings() const { return mSettings; }
 
-    PopupMenu * menu;
+    QDBusInterface *m_cloudInterface;
 
+    QMenu * menu;
+    QAction * m_lockAction;
+    /**
+     * @brief mDbusXrandInter
+     * 华为990双屏的dbus
+     */
+    QDBusInterface  *mDbusXrandInter;
+    QRect mcurrentScreenRect;
+    QString flag_hw990;
+
+    int MAX_SIZE_PANEL_IN_CALC;
+    int MID_SIZE_PANEL_IN_CALC;
+    int SML_SIZE_PANEL_IN_CALC;
+    int MAX_ICON_SIZE_IN_CLAC;
+    int MID_ICON_SIZE_IN_CLAC;
+    int SML_ICON_SIZE_IN_CLAC;
+    void getSize();
+    void connectToServer();
+    void caculateScreenGeometry();
+    int getScreenGeometry(QString methodName);
 
 private slots:
-    void setPanelPosition(Position position);
-    void setPanelsize(int panelsize);
-    void setIconsize(int iconsize);
-    void changeSizeToSmall();
-    void changeSizeToMedium();
-    void changeSizeToLarge();
     void panelReset();
-    void panelBackgroundChange();
+    void keyChangedSlot(const QString &key);
+    void priScreenChanged(int x, int y, int width, int height);
+
 
 public:
     QGSettings *gsettings;
     QGSettings *transparency_gsettings;
+    QTimer *time;
 
 };
 
