@@ -41,7 +41,7 @@
 #include <QTimer>
 
 #include "../panel/common/ukuigridlayout.h"
-
+#include <unistd.h>
 #include "ukuitaskbar.h"
 #include "ukuitaskgroup.h"
 using namespace UKUi;
@@ -70,6 +70,7 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
     mPlaceHolder(new QWidget(this)),
     mStyle(new LeftAlignedTextStyle())
 {
+    qDebug()<<"Plugin-Taskbar :: UKUITaskBar start";
     taskstatus=NORMAL;
     setAttribute(Qt::WA_TranslucentBackground);//设置窗口背景透明
     setWindowFlags(Qt::FramelessWindowHint);   //设置无边框窗口
@@ -86,13 +87,26 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
     mPlaceHolder->setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
     mPlaceHolder->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
     mLayout->addWidget(mPlaceHolder);
-    QTimer::singleShot(0, this, SLOT(refreshPlaceholderVisibility()));
-
+    QTimer::singleShot(0,[this] {refreshPlaceholderVisibility();});
 //    QTimer::singleShot(0, this, SLOT(settingsChanged()));
     settingsChanged();
 //    setButtonStyle(Qt::ToolButtonIconOnly);
     setAcceptDrops(true);
-
+    QGSettings *changeTheme;
+    const QByteArray id_Theme("org.ukui.style");
+    if(QGSettings::isSchemaInstalled(id_Theme)){
+        changeTheme = new QGSettings(id_Theme);
+    }
+    connect(changeTheme, &QGSettings::changed, this, [=] (const QString &key){
+        if(key=="iconThemeName"){
+            sleep(1);
+            for(auto it= mKnownWindows.begin(); it != mKnownWindows.end();it++)
+            {
+                UKUITaskGroup *group = it.value();
+                group->updateIcon();
+            }
+        }
+    });
     connect(mSignalMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped), this, &UKUITaskBar::activateTask);
     QTimer::singleShot(0, this, &UKUITaskBar::registerShortcuts);
 
@@ -116,6 +130,7 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
     QDBusConnection::sessionBus().unregisterService("com.ukui.panel.plugins.service");
     QDBusConnection::sessionBus().registerService("com.ukui.panel.plugins.service");
     QDBusConnection::sessionBus().registerObject("/taskbar/click", this,QDBusConnection :: ExportAllSlots | QDBusConnection :: ExportAllSignals);
+    qDebug()<<"Plugin-Taskbar :: UKUITaskBar end";
 }
 
 /************************************************
@@ -124,11 +139,6 @@ UKUITaskBar::UKUITaskBar(IUKUIPanelPlugin *plugin, QWidget *parent) :
 UKUITaskBar::~UKUITaskBar()
 {
     delete mStyle;
-    if(mpTaskBarIcon)
-    {
-        delete mpTaskBarIcon;
-        mpTaskBarIcon = nullptr;
-    }
 }
 
 /************************************************
@@ -144,6 +154,7 @@ bool UKUITaskBar::acceptWindow(WId window) const
     ignoreList |= NET::MenuMask;
     ignoreList |= NET::PopupMenuMask;
     ignoreList |= NET::NotificationMask;
+    ignoreList |= NET::UtilityMask;
 
     KWindowInfo info(window, NET::WMWindowType | NET::WMState, NET::WM2TransientFor);
     if (!info.valid())
@@ -170,6 +181,35 @@ bool UKUITaskBar::acceptWindow(WId window) const
     return !NET::typeMatchesMask(info.windowType(NET::AllTypesMask), normalFlag);
 }
 
+bool UKUITaskBar::ignoreSymbolCMP(QString filename,QString groupname) {
+    if (filename.isEmpty()) return false;
+    groupname.replace(" ", "");
+    groupname.replace("-", ".");
+    groupname.replace(".demo", "");
+    groupname.replace(".py", "");
+    groupname.replace("org.", "");
+    groupname.replace(".qt", "");
+    filename.replace(" ", "");
+    filename.replace("-", ".");
+    filename.replace("org.", "");
+    filename.replace(".desktop", "");
+    if (groupname.toLower().contains(filename.toLower(), Qt::CaseInsensitive))
+        return true;
+    if (filename.toLower().contains(groupname.toLower(), Qt::CaseInsensitive))
+        return true;
+    if (groupname.toLower().contains("kylinweather") && filename.toLower().contains("china.weather"))
+        return true;
+    if (groupname.toLower().contains("srhuijian") && filename.toLower().contains("huijian"))
+        return true;
+    if (groupname.contains("用户手册") && filename.toLower().contains("kylin.user.guid"))
+        return true;
+    if (groupname.toLower().contains("wpsoffice") && filename.toLower().contains("wps.office.prometheus"))
+        return true;
+    if (groupname.toLower().contains("ukuisystemmonitor") && filename.toLower().contains("ukui.system.monitor"))
+        return true;
+    return false;
+}
+
 /************************************************
 
  ************************************************/
@@ -296,12 +336,14 @@ void UKUITaskBar::addWindow(WId window)
 {
     // If grouping disabled group behaves like regular button
     const QString group_id = mGroupingEnabled ? KWindowInfo(window, 0, NET::WM2WindowClass).windowClassClass() : QString("%1").arg(window);
-#if (QT_VERSION < QT_VERSION_CHECK(5,7,0))
-    if(!group_id.compare("peony-qt-desktop"))
+    //针对ukui-menu和ukui-sidebar做的特殊处理，及时窗口是普通窗口，也不在任务栏显示
+    QStringList ignoreWindow;
+    ignoreWindow<<"ukui-menu"<<"ukui-sidebar"<<"ukui-search";
+    if(ignoreWindow.contains(group_id))
     {
+        qDebug()<<"ignoreWindow.contains(group_id)";
         return;
     }
-#endif
     UKUITaskGroup *group = nullptr;
     auto i_group = mKnownWindows.find(window);
     if (mKnownWindows.end() != i_group)
@@ -316,7 +358,9 @@ void UKUITaskBar::addWindow(WId window)
      * 安卓兼容应用的组名为kydroid-display-window
      * 需要将安卓兼容目录的分组特性关闭
     */
-    if (!group && mGroupingEnabled && group_id.compare("kydroid-display-window"))
+    QStringList andriod_window_list;
+    andriod_window_list<<"kydroid-display-window"<<"kylin-kmre-window";
+    if (!group && mGroupingEnabled && !andriod_window_list.contains(group_id))
     {
         for (auto i = mKnownWindows.cbegin(), i_e = mKnownWindows.cend(); i != i_e; ++i)
         {
@@ -433,7 +477,7 @@ void UKUITaskBar::refreshButtonRotation()
     bool autoRotate = mAutoRotate && (mButtonStyle != Qt::ToolButtonIconOnly);
 
     IUKUIPanel::Position panelPosition = mPlugin->panel()->position();
-    emit buttonRotationRefreshed(autoRotate, panelPosition);
+//    emit buttonRotationRefreshed(autoRotate, panelPosition);
 }
 
 /************************************************
