@@ -48,6 +48,7 @@
 #include <QStyleOptionToolButton>
 #include <QDesktopWidget>
 
+#include <unistd.h>
 #include "ukuitaskgroup.h"
 #include "ukuitaskbar.h"
 #include "../panel/customstyle.h"
@@ -117,6 +118,14 @@ UKUITaskButton::UKUITaskButton(QString appName,const WId window, UKUITaskBar * t
             updateIcon();
         }
     });
+
+    QStringList windowList;
+    //qDebug()<<"Window  Name"<<KWindowInfo(this->windowId(), 0, NET::WM2WindowClass).windowClassClass();
+    windowList<<"kylin-kmre-window"<<"kydroid-display-window";
+    if(windowList.contains(KWindowInfo(this->windowId(), 0, NET::WM2WindowClass).windowClassClass())){
+        connect(KWindowSystem::self(), static_cast<void (KWindowSystem::*)(WId, NET::Properties, NET::Properties2)>(&KWindowSystem::windowChanged)
+                , this, &UKUITaskButton::updateIcon);
+    }
 }
 
 /************************************************
@@ -141,8 +150,17 @@ void UKUITaskButton::updateText()
  * 目的是为了能够显示正确的application-x-desktop的图标的大小
  *
 */
+void UKUITaskButton::setLeaderWindow(WId leaderWindow) {
+    mWindow = leaderWindow;
+    updateIcon();
+}
+
 void UKUITaskButton::updateIcon()
 {
+    if (mAppName == QString("emo-system-ShellMethods") ||
+        mAppName == QString("Qq"))
+        sleep(1);
+
     QIcon ico;
     int mIconSize=mPlugin->panel()->iconSize();
     if (mParentTaskBar->isIconByClass())
@@ -158,10 +176,21 @@ void UKUITaskButton::updateIcon()
 #endif
         ico = KWindowSystem::icon(mWindow, devicePixels, devicePixels);
     }
-    setIcon(ico.isNull() ? QIcon::fromTheme("application-x-desktop") : ico);
+    if (mIcon.isNull()) {
+        mIcon = QIcon::fromTheme("application-x-desktop");
+    }
+    if (ico.isNull()) {
+        ico = mIcon;
+    }
+    setIcon(ico);
     setIconSize(QSize(mIconSize,mIconSize));
 }
 
+void UKUITaskButton::setGroupIcon(QIcon ico)
+{
+    mIcon = ico;
+}
+
 /************************************************
 
  ************************************************/
