@@ -52,6 +52,8 @@
 #include "../panel/iukuipanelplugin.h"
 #include <QSize>
 #include <QScreen>
+#include <XdgIcon>
+#include <XdgDesktopFile>
 #include "../panel/customstyle.h"
 
 #define PREVIEW_WIDTH		468
@@ -140,6 +142,7 @@ UKUITaskGroup::UKUITaskGroup(const QString &groupName, WId window, UKUITaskBar *
     mTimer(new QTimer(this)),
     mpWidget(NULL)
 {
+    qDebug()<<"Plugin-Taskbar :: UKUITaskGroup start";
     Q_ASSERT(parent);
     mpScrollArea = NULL;
     taskgroupStatus = NORMAL;
@@ -147,6 +150,13 @@ UKUITaskGroup::UKUITaskGroup(const QString &groupName, WId window, UKUITaskBar *
     setObjectName(groupName);
     setText(groupName);
 
+//    QTimer::singleShot(5000,[=] {
+//        if(window){
+//            initDesktopFileName(window);
+//            initActionsInRightButtonMenu();
+//        }
+//    });
+
     connect(this, SIGNAL(clicked(bool)), this, SLOT(onClicked(bool)));
     connect(KWindowSystem::self(), SIGNAL(currentDesktopChanged(int)), this, SLOT(onDesktopChanged(int)));
     connect(KWindowSystem::self(), SIGNAL(activeWindowChanged(WId)), this, SLOT(onActiveWindowChanged(WId)));
@@ -156,6 +166,7 @@ UKUITaskGroup::UKUITaskGroup(const QString &groupName, WId window, UKUITaskBar *
     connect(parent, &UKUITaskBar::popupShown, this, &UKUITaskGroup::groupPopupShown);
     mTimer->setTimerType(Qt::PreciseTimer);
     connect(mTimer, SIGNAL(timeout()), SLOT(timeout()));
+    qDebug()<<"Plugin-Taskbar :: UKUITaskGroup end";
 }
 
 UKUITaskGroup::~UKUITaskGroup()
@@ -177,6 +188,123 @@ UKUITaskGroup::~UKUITaskGroup()
 //    }
 }
 
+
+bool DesktopFileNameCompare(QString str1, QString str2) {
+    if (str1 == str2)
+        return true;
+    if (str2.contains(str1))
+        return true;
+    if (str1.contains(str2))
+        return true;
+    return false;
+}
+
+QString getDesktopFileName(QString cmd) {
+    char name[200];
+    FILE *fp1 = NULL;
+    if ((fp1 = popen(cmd.toStdString().data(), "r")) == NULL)
+        return QString();
+    memset(name, 0, sizeof(name));
+    fgets(name, sizeof(name),fp1);
+    pclose(fp1);
+    return QString(name);
+}
+
+void UKUITaskGroup::badBackFunctionToFindDesktop() {
+    if (file_name.isEmpty()) {
+        QDir dir("/usr/share/applications/");
+        QFileInfoList list = dir.entryInfoList();
+        for (int i = 0; i < list.size(); i++) {
+            QFileInfo fileInfo = list.at(i);
+            if (parentTaskBar()->ignoreSymbolCMP(fileInfo.filePath(), groupName())) {
+                file_name = fileInfo.filePath();
+                if (file_name == QString(PEONY_COMUTER) ||
+                    file_name == QString(PEONY_TRASH) ||
+                    file_name == QString(PEONY_HOME))
+                    file_name = QString(PEONY_MAIN);
+                break;
+            }
+        }
+    }
+}
+
+void UKUITaskGroup::initDesktopFileName(WId window) {
+    KWindowInfo info(window, 0, NET::WM2DesktopFileName);
+    QString cmd;
+    cmd.sprintf(GET_PROCESS_EXEC_NAME_MAIN, info.pid());
+    QString processExeName = getDesktopFileName(cmd);
+
+    QDir dir(DEKSTOP_FILE_PATH);
+    QFileInfoList list = dir.entryInfoList();
+    for (int i = 0; i < list.size(); i++) {
+        bool flag = false;
+        QFileInfo fileInfo = list.at(i);
+        QString _cmd;
+        if (fileInfo.filePath() == QString(USR_SHARE_APP_CURRENT) ||
+            fileInfo.filePath() == QString(USR_SHARE_APP_UPER) )
+            continue;
+        _cmd.sprintf(GET_DESKTOP_EXEC_NAME_MAIN, fileInfo.filePath().toStdString().data());
+        QString desktopFileExeName = getDesktopFileName(_cmd);
+        flag = DesktopFileNameCompare(desktopFileExeName, processExeName);
+        if (flag && !desktopFileExeName.isEmpty()) {
+            file_name = fileInfo.filePath();
+            if (file_name == QString(PEONY_COMUTER) ||
+                file_name == QString(PEONY_TRASH) ||
+                file_name == QString(PEONY_HOME) )
+                file_name = QString(PEONY_MAIN);
+            break;
+        }
+    }
+    if (file_name.isEmpty()) {
+        for (int i = 0; i < list.size(); i++) {
+            bool flag = false;
+            QFileInfo fileInfo = list.at(i);
+            if (fileInfo.filePath() == QString(USR_SHARE_APP_CURRENT) ||
+                fileInfo.filePath() == QString(USR_SHARE_APP_UPER) )
+                continue;
+            QString _cmd;
+            _cmd.sprintf(GET_DESKTOP_EXEC_NAME_BACK, fileInfo.filePath().toStdString().data());
+            QString desktopFileExeName = getDesktopFileName(_cmd);
+            flag = DesktopFileNameCompare(desktopFileExeName, processExeName);
+            if (flag && !desktopFileExeName.isEmpty()) {
+                file_name = fileInfo.filePath();
+                if (file_name == QString(PEONY_COMUTER) ||
+                    file_name == QString(PEONY_TRASH) ||
+                    file_name == QString(PEONY_HOME) )
+                    file_name = QString(PEONY_MAIN);
+                break;
+            }
+        }
+    }
+    badBackFunctionToFindDesktop();
+}
+
+void UKUITaskGroup::initActionsInRightButtonMenu(){
+    if (file_name.isEmpty()) return;
+    const auto url=QUrl(file_name);
+    QString fileName(url.isLocalFile() ? url.toLocalFile() : url.url());
+    QFileInfo fi(fileName);
+    XdgDesktopFile xdg;
+    if (xdg.load(fileName))
+    {
+        /*This fuction returns true if the desktop file is applicable to the
+          current environment.
+          but I don't need this attributes now
+        */
+        //        if (xdg.isSuitable())
+        mAct = new QuickLaunchAction(&xdg, this);
+    }
+    else if (fi.exists() && fi.isExecutable() && !fi.isDir())
+    {
+        mAct = new QuickLaunchAction(fileName, fileName, "", this);
+    }
+    else if (fi.exists())
+    {
+        mAct = new QuickLaunchAction(fileName, this);
+    }
+    setGroupIcon(mAct->getIconfromAction());
+}
+
 /************************************************
 
  ************************************************/
@@ -192,8 +320,8 @@ void UKUITaskGroup::contextMenuEvent(QContextMenuEvent *event)
 
     QMenu * menu = new QMenu(tr("Group"));
     menu->setAttribute(Qt::WA_DeleteOnClose);
-    QAction *a = menu->addAction(QIcon::fromTheme("process-stop"), tr("close"));
-    connect(a, SIGNAL(triggered()), this, SLOT(closeGroup()));
+    QAction *close = menu->addAction(QIcon::fromTheme("window-close-symbolic"), tr("close"));
+    connect(close, SIGNAL(triggered()), this, SLOT(closeGroup()));
     connect(menu, &QMenu::aboutToHide, [this] {
         mPreventPopup = false;
     });
@@ -216,6 +344,9 @@ void UKUITaskGroup::closeGroup()
             button->closeApplication();
     }
 #else
+    for (UKUITaskWidget *button : qAsConst(mButtonHash) )
+        if (button->isOnDesktop(KWindowSystem::currentDesktop()))
+            button->minimizeApplication();
     for (UKUITaskWidget *button : qAsConst(mButtonHash) )
         if (button->isOnDesktop(KWindowSystem::currentDesktop()))
             button->closeApplication();
@@ -257,7 +388,7 @@ QWidget * UKUITaskGroup::checkedButton() const
  */
 void UKUITaskGroup::changeTaskButtonStyle()
 {
-    if(mButtonHash.size()>1)
+    if(mVisibleHash.size()>1)
         this->setStyle(new CustomStyle("taskbutton",true));
     else
         this->setStyle(new CustomStyle("taskbutton",false));
@@ -334,6 +465,7 @@ void UKUITaskGroup::onActiveWindowChanged(WId window)
 void UKUITaskGroup::onDesktopChanged(int number)
 {
     refreshVisibility();
+    changeTaskButtonStyle();
 }
 
 /************************************************
@@ -351,6 +483,8 @@ void UKUITaskGroup::onWindowRemoved(WId window)
         button->deleteLater();
         if (!parentTaskBar()->getCpuInfoFlg())
             system(QString("rm -f /tmp/%1.png").arg(window).toLatin1());
+        if (isLeaderWindow(window))
+            setLeaderWindow(mButtonHash.begin().key());
         if (mButtonHash.count())
         {
             if(mPopup->isVisible())
@@ -467,7 +601,8 @@ void UKUITaskGroup::onClicked(bool)
 {
     if (1 == mVisibleHash.size())
     {
-        return singleWindowClick();
+        singleWindowClick();
+        return;
     }
     if(mPopup->isVisible())
     {
@@ -496,7 +631,7 @@ void UKUITaskGroup::onClicked(bool)
 
 void UKUITaskGroup::singleWindowClick()
 {
-    UKUITaskWidget *btn = mButtonHash.begin().value();
+    UKUITaskWidget *btn = mVisibleHash.value(windowId());
     if(btn)
     {
         if(!btn->isFocusState())
@@ -505,7 +640,7 @@ void UKUITaskGroup::singleWindowClick()
             {
                 mPopup->hide();
             }
-            KWindowSystem::activateWindow(mButtonHash.begin().key());
+            KWindowSystem::activateWindow(windowId());
         }
         else
         {
@@ -607,9 +742,14 @@ void UKUITaskGroup::refreshVisibility()
         btn->setVisible(visible);
         if (btn->isVisibleTo(mPopup) && !mVisibleHash.contains(i.key()))
             mVisibleHash.insert(i.key(), i.value());
+        else if (!btn->isVisibleTo(mPopup) && mVisibleHash.contains(i.key())) {
+            mVisibleHash.remove(i.key());
+            if (isLeaderWindow(btn->windowId()) && !will) {
+                setLeaderWindow(btn->windowId());
+            }
+        }
         will |= visible;
     }
-
     bool is = isVisible();
     setVisible(will);
     if(!mPopup->isVisible())
@@ -871,8 +1011,11 @@ bool UKUITaskGroup::onWindowChanged(WId window, NET::Properties prop, NET::Prope
 
         // XXX: we are setting window icon geometry -> don't need to handle NET::WMIconGeometry
         // Icon of the button can be based on windowClass
-//        if (prop.testFlag(NET::WMIcon) || prop2.testFlag(NET::WM2WindowClass))
-//            std::for_each(buttons.begin(), buttons.end(), std::mem_fn(&UKUITaskButton::updateIcon));
+        if (prop.testFlag(NET::WMIcon) || prop2.testFlag(NET::WM2WindowClass)){
+            updateIcon();
+            for(UKUITaskButtonHash::const_iterator i=mVisibleHash.begin();i!= mVisibleHash.end();i++)
+                i.value()->updateIcon();
+        }
 
         if (prop.testFlag(NET::WMState))
         {
@@ -1007,7 +1150,9 @@ bool UKUITaskGroup::isSetMaxWindow()
 
 void UKUITaskGroup::showPreview()
 {
-    if(mVisibleHash.size()<=10)
+    int n = 7;
+    if (plugin()->panel()->isHorizontal()) n = 10;
+    if(mVisibleHash.size() <= n)
     {
         showAllWindowByThumbnail();
     }
@@ -1034,17 +1179,19 @@ void UKUITaskGroup::adjustPopWindowSize(int winWidth, int winHeight)
 void UKUITaskGroup::v_adjustPopWindowSize(int winWidth, int winHeight, int v_all)
 {
     int fixed_size = v_all;
-    int iScreenWidth = QApplication::screens().at(0)->size().width();
-
-    if (fixed_size > iScreenWidth)
-        fixed_size = iScreenWidth;
 
     if(plugin()->panel()->isHorizontal())
     {
+        int iScreenWidth = QApplication::screens().at(0)->size().width();
+        if (fixed_size > iScreenWidth)
+            fixed_size = iScreenWidth;
         mPopup->setFixedSize(fixed_size,  winHeight + 6);
     }
     else
     {
+        int iScreenHeight = QApplication::screens().at(0)->size().height();
+        if (fixed_size > iScreenHeight)
+            fixed_size = iScreenHeight;
         mPopup->setFixedSize(winWidth + 6, fixed_size);
     }
     mPopup->adjustSize();
@@ -1052,7 +1199,6 @@ void UKUITaskGroup::v_adjustPopWindowSize(int winWidth, int winHeight, int v_all
 
 void UKUITaskGroup::timeout()
 {
-
     if(mTaskGroupEvent == ENTEREVENT)
     {
         if(mTimer->isActive())
@@ -1101,7 +1247,8 @@ int UKUITaskGroup::calcAverageWidth()
         int size = mVisibleHash.size();
         int iScreenWidth = QApplication::screens().at(0)->size().width();
         int iMarginWidth = (size+1)*3;
-        int iAverageWidth = (iScreenWidth - iMarginWidth)/size;//calculate average width of window
+        int iAverageWidth;
+        iAverageWidth = (size == 0 ? size : (iScreenWidth - iMarginWidth)/size);//calculate average width of window
         return iAverageWidth;
     }
     else
@@ -1116,7 +1263,7 @@ void UKUITaskGroup::showAllWindowByList()
     int winWidth = 246;
     int winheight = 46;
     int iPreviewPosition = 0;
-    int popWindowheight =( winheight - 2) * mVisibleHash.size() + 3;
+    int popWindowheight = (winheight) * (mVisibleHash.size());
     int screenAvailabelHeight = QApplication::screens().at(0)->size().height() - plugin()->panel()->panelSize();
     if(!plugin()->panel()->isHorizontal())
     {
@@ -1126,38 +1273,38 @@ void UKUITaskGroup::showAllWindowByList()
     {
         removeSrollWidget();
     }
-    mpScrollArea = new QScrollArea();
+    mpScrollArea = new QScrollArea(this);
     mpScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     mpScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 
-    mpScrollArea->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    //mpScrollArea->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     mpScrollArea->setWidgetResizable(true);
-    mpScrollArea->setFixedWidth(winWidth-10);
     mpScrollArea->setFrameStyle(QFrame::NoFrame);
 
     mPopup->layout()->addWidget(mpScrollArea);
-    mpWidget = new QWidget();
-    mpWidget->setFixedWidth(mpScrollArea->width());
+    mPopup->setFixedSize(winWidth,  popWindowheight < screenAvailabelHeight? popWindowheight : screenAvailabelHeight);
+    mpWidget = new QWidget(this);
     mpScrollArea->setWidget(mpWidget);
-    //mpWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-//    mpWidget->setAttribute(Qt::WA_TranslucentBackground);
     setLayOutForPostion();
+
     /*begin catch preview picture*/
-    for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
+    for (UKUITaskButtonHash::const_iterator it = mVisibleHash.begin();it != mVisibleHash.end();it++)
     {
         UKUITaskWidget *btn = it.value();
+        btn->clearMask();
+        btn->setTitleFixedWidth(mpWidget->width() - 25);
+        btn->setParent(mpScrollArea);
         btn->removeThumbNail();
-        btn->updateTitle();
-        btn->setTitleFixedWidth(winWidth - 80);
-//        btn->setFixedSize(mpScrollArea->width(),winheight);
+        btn->addThumbNail();
         btn->adjustSize();
-        mpWidget->layout()->setContentsMargins(0,0,0,0);
+        btn->setFixedHeight(winheight);
+
+        connect(btn, &UKUITaskWidget::closeSigtoPop, [this] { mPopup->pubcloseWindowDelay(); });
+        connect(btn, &UKUITaskWidget::closeSigtoGroup, [this] { closeGroup(); });
         mpWidget->layout()->addWidget(btn);
     }
     /*end*/
     plugin()->willShowWindow(mPopup);
-    mPopup->setFixedSize(winWidth,  popWindowheight < screenAvailabelHeight? popWindowheight : screenAvailabelHeight);
-    mPopup->adjustSize();
     if(plugin()->panel()->isHorizontal())
     {
         iPreviewPosition =  plugin()->panel()->panelSize()/2 - winWidth/2;
@@ -1168,9 +1315,9 @@ void UKUITaskGroup::showAllWindowByList()
         iPreviewPosition = plugin()->panel()->panelSize()/2 - winWidth/2;
         mPopup->setGeometry(plugin()->panel()->calculatePopupWindowPos(mapToGlobal(QPoint(0,iPreviewPosition)), mPopup->size()));
     }
+    mpScrollArea->show();
     mPopup->show();
-
-   emit popupShown(this);
+//   emit popupShown(this);
 }
 
 
@@ -1183,6 +1330,7 @@ void UKUITaskGroup::showAllWindowByThumbnail()
     int previewPosition = 0;
     int winWidth = 0;
     int winHeight = 0;
+    int truewidth = 0;
    // initVisibleHash();
     refreshVisibility();
     int iAverageWidth = calcAverageWidth();
@@ -1193,7 +1341,6 @@ void UKUITaskGroup::showAllWindowByThumbnail()
     {
         if(0 == iAverageWidth)
         {
-
             winHeight = PREVIEW_WIDGET_MAX_HEIGHT < iAverageHeight?PREVIEW_WIDGET_MAX_HEIGHT:iAverageHeight;
             winWidth = winHeight*PREVIEW_WIDGET_MAX_WIDTH/PREVIEW_WIDGET_MAX_HEIGHT;
         }
@@ -1222,7 +1369,7 @@ void UKUITaskGroup::showAllWindowByThumbnail()
     {
         removeWidget();
     }
-    mpWidget = new QWidget;
+    mpWidget = new QWidget(this);
     mpWidget->setAttribute(Qt::WA_TranslucentBackground);
     setLayOutForPostion();
     /*begin catch preview picture*/
@@ -1234,20 +1381,24 @@ void UKUITaskGroup::showAllWindowByThumbnail()
     int title_width = 0;
     int v_all = 0;
     int iScreenWidth = QApplication::screens().at(0)->size().width();
-    float minimumWidth = THUMBNAIL_WIDTH;
     float minimumHeight = THUMBNAIL_HEIGHT;
-    for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
+    for (UKUITaskButtonHash::const_iterator it = mVisibleHash.begin();it != mVisibleHash.end();it++)
     {
+        it.value()->removeThumbNail();
         display = XOpenDisplay(nullptr);
         XGetWindowAttributes(display, it.key(), &attr);
         max_Height = attr.height > max_Height ? attr.height : max_Height;
         max_Width = attr.width > max_Width ? attr.width : max_Width;
+        truewidth += attr.width;
         if(display)
             XCloseDisplay(display);
     }
     for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
     {
         UKUITaskWidget *btn = it.value();
+        btn->setParent(mPopup);
+        connect(btn, &UKUITaskWidget::closeSigtoPop, [this] { mPopup->pubcloseWindowDelay(); });
+        connect(btn, &UKUITaskWidget::closeSigtoGroup, [this] { closeGroup(); });
         btn->addThumbNail();
         display = XOpenDisplay(nullptr);
         XGetWindowAttributes(display, it.key(), &attr);
@@ -1255,28 +1406,24 @@ void UKUITaskGroup::showAllWindowByThumbnail()
         float imgWidth = 0;
         float imgHeight = 0;
         if (plugin()->panel()->isHorizontal()) {
-            imgWidth = (float)attr.width / (float)attr.height * THUMBNAIL_HEIGHT;
-            imgHeight = THUMBNAIL_HEIGHT;
+            float thmbwidth = (float)attr.width / (float)attr.height;
+                imgWidth = thmbwidth * winHeight;
+                imgHeight = winHeight;
+                if (imgWidth > THUMBNAIL_WIDTH)
+                    imgWidth = THUMBNAIL_WIDTH;
         } else {
             imgWidth = THUMBNAIL_WIDTH;
             imgHeight = (float)attr.height / (float)attr.width * THUMBNAIL_WIDTH;
         }
         if (plugin()->panel()->isHorizontal())
         {
-            if (attr.height != max_Height)
-            {
-                float tmp = (float)attr.height / (float)max_Height;
-                imgHeight =  imgHeight * tmp;
-            }
-            if ((int)imgWidth > (int)minimumWidth)
-            {
-                imgWidth = minimumWidth;
-            }
-            if (btn->isVisibleTo(mPopup)) {
+            if (mVisibleHash.contains(btn->windowId())) {
                 v_all += (int)imgWidth;
                 imgWidth_sum += (int)imgWidth;
             }
-            if (mVisibleHash.size() == 1 ) changed = (int)imgWidth;
+            if (mVisibleHash.size() == 1 ) {
+                changed = (int)imgWidth;
+            }
             btn->setThumbMaximumSize(MAX_SIZE_OF_Thumb);
             btn->setThumbScale(true);
         } else {
@@ -1289,7 +1436,7 @@ void UKUITaskGroup::showAllWindowByThumbnail()
             {
                 imgHeight = minimumHeight;
             }
-            if (btn->isVisibleTo(mPopup)) {
+            if (mVisibleHash.contains(btn->windowId())) {
                 v_all += (int)imgHeight;
             }
             if (mVisibleHash.size() == 1 ) changed = (int)imgHeight;
@@ -1333,7 +1480,6 @@ void UKUITaskGroup::showAllWindowByThumbnail()
         }
     }
     /*end*/
-    int i = 0;
         for (UKUITaskButtonHash::const_iterator it = mButtonHash.begin();it != mButtonHash.end();it++)
         {
             UKUITaskWidget *btn = it.value();
@@ -1392,6 +1538,5 @@ void UKUITaskGroup::showAllWindowByThumbnail()
     {
         mPopup->show();
     }
-
-   emit popupShown(this);
+//   emit popupShown(this);
 }
