@@ -93,17 +93,16 @@ UKUITaskWidget::UKUITaskWidget(const WId window, UKUITaskBar * taskbar, QWidget
 //    mCloseBtn->setIcon(QIcon::fromTheme("window-close-symbolic"));
     mCloseBtn->setIconSize(QSize(19,19));
     mCloseBtn->setFixedSize(QSize(19,19));
-    mCloseBtn->hide();
-    mTitleLabel = new QLabel;
+    mTitleLabel = new QLabel(this);
     mTitleLabel->setMargin(0);
     //    mTitleLabel->setContentsMargins(0,0,0,10);
     //    mTitleLabel->adjustSize();
     //    mTitleLabel->setStyleSheet("QLabel{background-color: red;}");
 
-    mThumbnailLabel = new QLabel;
-    mAppIcon = new QLabel;
-    mVWindowsLayout = new QVBoxLayout;
-    mTopBarLayout = new QHBoxLayout;
+    mThumbnailLabel = new QLabel(this);
+    mAppIcon = new QLabel(this);
+    mVWindowsLayout = new QVBoxLayout(this);
+    mTopBarLayout = new QHBoxLayout(this);
     mTopBarLayout->setContentsMargins(0,0,0,0);
     //    mTopBarLayout->setAlignment(Qt::AlignVCenter);
     //    mTopBarLayout->setDirection(QBoxLayout::LeftToRight);
@@ -137,10 +136,11 @@ UKUITaskWidget::UKUITaskWidget(const WId window, UKUITaskBar * taskbar, QWidget
     //    mTopBarLayout->setSpacing(5);
     mTopBarLayout->addWidget(mAppIcon, 0, Qt::AlignLeft | Qt::AlignVCenter);
     mTopBarLayout->addWidget(mTitleLabel, 10, Qt::AlignLeft);
+    mTopBarLayout->addWidget(mCloseBtn, 0, Qt::AlignRight);
     //    mTopBarLayout->addStretch();
 //    mTopBarLayout->addWidget(mCloseBtn, 0, Qt::AlignRight | Qt::AlignVCenter);
     //    mVWindowsLayout->setAlignment(Qt::AlignCenter);
-    mVWindowsLayout->addLayout(mTopBarLayout, 5);
+    mVWindowsLayout->addLayout(mTopBarLayout);
     mVWindowsLayout->addWidget(mThumbnailLabel, Qt::AlignCenter, Qt::AlignCenter);
     mVWindowsLayout->setSizeConstraint(QLayout::SetMinAndMaxSize);
     this->setLayout(mVWindowsLayout);
@@ -159,6 +159,7 @@ UKUITaskWidget::UKUITaskWidget(const WId window, UKUITaskBar * taskbar, QWidget
 ************************************************/
 UKUITaskWidget::~UKUITaskWidget()
 {
+    this->deleteLater();
 }
 
 /************************************************
@@ -308,7 +309,6 @@ void UKUITaskWidget::mouseReleaseEvent(QMouseEvent* event)
         raiseApplication();
     }
     status = NORMAL;
-    mTopBarLayout->removeWidget(mCloseBtn);
     update();
     QWidget::mouseReleaseEvent(event);
 
@@ -321,16 +321,12 @@ void UKUITaskWidget::mouseReleaseEvent(QMouseEvent* event)
 void UKUITaskWidget::enterEvent(QEvent *)
 {
     status = HOVER;
-    mTopBarLayout->addWidget(mCloseBtn, 0, Qt::AlignRight | Qt::AlignVCenter);
-    mCloseBtn->show();
     repaint();
 }
 
 void UKUITaskWidget::leaveEvent(QEvent *)
 {
     status = NORMAL;
-    mTopBarLayout->removeWidget(mCloseBtn);
-    mCloseBtn->hide();
     repaint();
 }
 QMimeData * UKUITaskWidget::mimeData()
@@ -350,6 +346,42 @@ void UKUITaskWidget::mouseMoveEvent(QMouseEvent* event)
 {
 }
 
+void UKUITaskWidget::closeGroup() {
+    printf("\n....\n");
+    emit closeSigtoGroup();
+}
+
+void UKUITaskWidget::contextMenuEvent(QContextMenuEvent *event)
+{
+    QMenu * menu = new QMenu(tr("Widget"));
+    menu->setAttribute(Qt::WA_DeleteOnClose);
+    /* 对应预览图右键功能 关闭 还原 最大化  最小化 置顶 取消置顶*/
+    QAction *close = menu->addAction(QIcon::fromTheme("window-close-symbolic"), tr("close"));
+    QAction *restore = menu->addAction(QIcon::fromTheme("window-restore-symbolic"), tr("restore"));
+
+    QAction *maxim = menu->addAction(QIcon::fromTheme("window-maximize-symbolic"), tr("maximaze"));
+
+    QAction *minim = menu->addAction(QIcon::fromTheme("window-minimize-symbolic"), tr("minimize"));
+    QAction *above = menu->addAction(QIcon::fromTheme("ukui-fixed"), tr("above"));
+    QAction *clear = menu->addAction(QIcon::fromTheme("ukui-unfixed"), tr("clear"));
+
+    connect(close, SIGNAL(triggered()), this, SLOT(closeApplication()));
+    connect(restore, SIGNAL(triggered()), this, SLOT(deMaximizeApplication()));
+    connect(maxim, SIGNAL(triggered()), this, SLOT(maximizeApplication()));
+    connect(minim, SIGNAL(triggered()), this, SLOT(minimizeApplication()));
+    connect(above, SIGNAL(triggered()), this, SLOT(setWindowKeepAbove()));
+    connect(clear, SIGNAL(triggered()), this, SLOT(setWindowStatusClear()));
+    connect(menu, &QMenu::aboutToHide, [this] {
+        emit closeSigtoPop();
+
+    });
+    KWindowInfo info(mWindow, NET::WMState);
+    above->setEnabled(!(info.state() & NET::KeepAbove));
+    clear->setEnabled(info.state() & NET::KeepAbove);
+    menu->setGeometry(plugin()->panel()->calculatePopupWindowPos(mapToGlobal(event->pos()), menu->sizeHint()));
+    plugin()->willShowWindow(menu);
+    menu->show();
+}
 /************************************************
 
  ************************************************/
@@ -359,6 +391,7 @@ bool UKUITaskWidget::isApplicationHidden() const
     return (info.state() & NET::Hidden);
 }
 
+
 /************************************************
 
  ************************************************/
@@ -448,6 +481,18 @@ void UKUITaskWidget::deMaximizeApplication()
         raiseApplication();
 }
 
+
+void UKUITaskWidget::setWindowKeepAbove()
+{
+    if (!isApplicationActive())
+        raiseApplication();
+    KWindowSystem::setState(mWindow, NET::KeepAbove);
+}
+
+void UKUITaskWidget::setWindowStatusClear()
+{
+    KWindowSystem::clearState(mWindow, NET::KeepAbove);
+}
 /************************************************
 
  ************************************************/
@@ -467,10 +512,13 @@ void UKUITaskWidget::unShadeApplication()
 /************************************************
 
  ************************************************/
+//void UKUITaskWidget::priv_closeApplication() {
+
+//}
+
 void UKUITaskWidget::closeApplication()
 {
     // FIXME: Why there is no such thing in KWindowSystem??
-    qDebug()<<"closeApplication";
     NETRootInfo(QX11Info::connection(), NET::CloseWindow).closeWindowRequest(mWindow);
 }
 
@@ -732,7 +780,6 @@ void UKUITaskWidget::paintEvent(QPaintEvent *event)
     case NORMAL:
     {
         p.fillPath(rectPath, QColor(0x13,0x14,0x14,0xb2));
-        mTopBarLayout->removeWidget(mCloseBtn);
         break;
     }
     case HOVER:
@@ -781,11 +828,11 @@ void UKUITaskWidget::addThumbNail()
 {
     if(!mThumbnailLabel)
     {
-        mThumbnailLabel =  new QLabel;
+        mThumbnailLabel = new QLabel(this);
         mThumbnailLabel->setScaledContents(true);
         mThumbnailLabel->setMinimumSize(QSize(1, 1));
         //        mVWindowsLayout->addLayout(mTopBarLayout, 100);
-        mVWindowsLayout->addWidget(mThumbnailLabel, 0, Qt::AlignBottom);
+        mVWindowsLayout->addWidget(mThumbnailLabel, 0, Qt::AlignCenter);
     }
     else
     {
