@@ -17,11 +17,14 @@ class MainController : public QObject
 public:
     static MainController* self();
     virtual ~MainController();
+    int init();
 private:
     explicit MainController();
-    void init();
-    void creatDBusService();
-    int IsNotRunning();
+
+public:
+Q_SIGNALS:
+    void notifyWnd(QObject* obj, QEvent *event);
+    
 private:
     static MainController *mSelf;
     MainWindow *m_DiskWindow;
