@@ -24,36 +24,34 @@
 #include <QDebug>
 #include <QtDBus/QDBusConnection>
 #include <QTranslator>
+#include <QTextCodec>
+//#include <ukui-log4qt.h>
 #include "UnionVariable.h"
 #include "mainwindow.h"
 #include "MainController.h"
+#include "fdapplication.h"
 
 int main(int argc, char *argv[])
 {
-    //file lock to complete the single process
-//    QStringList homePath = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
-//    QString lockPath = homePath.at(0) + "/.config/ukui-flash-disk-lock";
-//    int fd = open(lockPath.toUtf8().data(), O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
-//    if (fd < 0)
-//    {
-//        exit(1);
-//    }
+//    initUkuiLog4qt("ukui-flash-disk");
+    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 
-//    if (lockf(fd, F_TLOCK, 0))
-//    {
-//        syslog(LOG_ERR, "Can't lock single file, ukui-flash-disk is already running!");
-//        qDebug()<<"Can't lock single file, ukui-flash-disk is already running!";
-//        exit(0);
-//    }
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    QApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
+#endif
 
-
-
-    QIcon::setThemeName("ukui-icon-theme-default");
+    QTextCodec *codec = QTextCodec::codecForName("utf8"); //Linux
+    QTextCodec::setCodecForLocale(codec);
 
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QApplication a(argc, argv);
+    QString id = QString("ukui-flash-disk_%1_%2").arg(getuid()).arg(QLatin1String(getenv("DISPLAY")));
+    FDApplication a(id, argc, argv);
     a.setQuitOnLastWindowClosed(false);        //Process does not exit implicitly
-
+    if (a.isRunning()) {
+        qInfo()<<"ukui-flash-disk is running, now exit!";
+        return 1;
+    }
 
     //load translation file
     QString locale = QLocale::system().name();
@@ -62,22 +60,15 @@ int main(int argc, char *argv[])
     {
         if (translator.load("/usr/share/ukui/ukui-panel/ukui-flash-disk_zh_CN.qm"))
         {
+            qDebug() << "load success";
             a.installTranslator(&translator);
         }
         else
         {
             qDebug() << "Load translations file" << locale << "failed!";
         }
-
     }
 
-    //load qss
-    QFile qss(":ukui-flash-disk.qss");
-    bool ok = qss.open(QFile::ReadOnly);
-    if (!ok)
-    qDebug() << "加载失败";
-    qApp->setStyleSheet(qss.readAll());
-
     if (QApplication::desktop()->width() >= 2560)
     {
         #if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
@@ -86,9 +77,10 @@ int main(int argc, char *argv[])
         #endif
     }
 
-    qss.close();
     MainController *ctrl = MainController::self();
-
+    if (ctrl->init() != 0)  // single instance is running
+        return 0;
+    QObject::connect(&a, &FDApplication::notifyWnd, ctrl, &MainController::notifyWnd);
     a.exec();
     delete ctrl;
     return 0;
