@@ -28,12 +28,19 @@
 #include <QApplication>
 #include <QEvent>
 #include <qgsettings.h>
+#include <QMap>
+#include <vector>
+
+using namespace std;
 
 #include "qclickwidget.h"
 #include "UnionVariable.h"
 #include "ejectInterface.h"
 #include "mainwindow.h"
 #include "MacroFile.h"
+#include "flashdiskdata.h"
+#include "fdclickwidget.h"
+#include "repair-dialog-box.h"
 
 
 namespace Ui {
@@ -53,7 +60,7 @@ class MainWindow : public QMainWindow
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
-    void MainWindowShow();
+    void MainWindowShow(bool isUpdate = false);
 
 protected:
     void hideEvent(QHideEvent event);
@@ -66,6 +73,7 @@ private:
     QPushButton *eject_image_button;
     void newarea(int No,
                  GDrive *Drive,
+                 GVolume *Volume,
                  QString Drivename,
                  QString nameDis1,
                  QString nameDis2,
@@ -80,6 +88,15 @@ private:
                  QString pathDis3,
                  QString pathDis4,
                  int linestatus);
+    void newarea(unsigned uDiskNo,
+                 QString strDriveId,
+                 QString strVolumeId,
+                 QString strMountId,
+                 QString driveName,
+                 QString volumeName,
+                 quint64 capacityDis,
+                 QString strMountUri,
+                 int linestatus);
     void moveBottomRight();
     void moveBottomDirect(GDrive *drive);
     void moveBottomNoBase();
@@ -95,6 +112,21 @@ private:
     static void volume_removed_callback (GVolumeMonitor *monitor, GVolume *volume, MainWindow *p_this);
     static void mount_added_callback (GVolumeMonitor *monitor, GMount *mount, MainWindow *p_this);
     static void mount_removed_callback (GVolumeMonitor *monitor, GMount *mount, MainWindow *p_this);
+    void ifgetPinitMount();
+    static void frobnitz_force_result_func(GDrive *source_object,GAsyncResult *res,MainWindow *p_this);
+    static void frobnitz_result_func(GDrive *source_object,GAsyncResult *res,MainWindow *p_this);
+    static void frobnitz_normal_result_volume_eject(GVolume *source_object,GAsyncResult *res,MainWindow *p_this);
+    static void frobnitz_force_result_unmount(GMount *source_object,GAsyncResult *res,MainWindow *p_this);
+    static void AsyncUnmount(QString strMountRoot,MainWindow *p_this);
+
+    void getSystemRootDev();
+    bool isSystemRootDev(QString strDev);
+
+    bool doRealEject(EjectDeviceInfo* peDeviceInfo, GMountUnmountFlags flag);
+    static GAsyncReadyCallback fileEjectMountableCB(GFile *file, GAsyncResult *res, EjectDeviceInfo *peDeviceInfo);
+    static void driveStopCb(GObject* object, GAsyncResult* res, EjectDeviceInfo *peDeviceInfo);
+
+    bool getDataCDRomCapacity(QString strDevId, quint64 &totalCapacity);
 
 private:
     QIcon iconSystray;
@@ -112,6 +144,7 @@ private:
     quint64 totalDis4;
 //    QClickWidget *open_widget;
     QClickWidget *open_widget;
+    FDClickWidget *m_fdClickWidget;
     int hign;
     int VolumeNum;
     QTimer *interfaceHideTime;
@@ -119,47 +152,84 @@ private:
     QScreen *screen;
     int triggerType = 0; //detective the type of MainWinow(insert USB disk or click systemtray icon)
 
-    char *mount_uri;
-    GFile *root;
-    GList *listVolumes;
-    GList *vList;
-    GVolume *volume;
-
     double m_transparency;
-    QGSettings *m_transparency_gsettings = nullptr;
+    QString currentThemeMode;
 
+    QGSettings *m_transparency_gsettings = nullptr;
+    QGSettings *qtSettings = nullptr;
+
+    QWidget *line = nullptr;
+    bool ifautoload;
+    bool insertorclick;
+
+    QGSettings * ifsettings = nullptr;
+    int telephoneNum;
+    QString tmpPath;
+    bool findPointMount;
+    int driveVolumeNum;
+    FlashDiskData* m_dataFlashDisk = nullptr;
+    bool m_bIsMouseInTraIcon = false;
+    bool m_bIsMouseInCentral = false;
+    qint64 m_nAppStartTimestamp = 0; // 进程启动时的时间戳
+    QString m_strSysRootDev;
     //authority
     //QDBusInterface *systemIface;
 public:
     QSystemTrayIcon *m_systray;
-    ejectInterface *m_eject;
+    ejectInterface *m_eject = nullptr;
+    interactiveDialog *chooseDialog = nullptr;
 
     void initTransparentState();
+    void initThemeMode();
 //    double getTransparentData();
     void getTransparentData();
     int getPanelPosition(QString str);
     int getPanelHeight(QString str);
-
     bool ifSucess;
     int flagType;
 //    static bool isShow;
     int driveMountNum;
+    vector<string> m_vtDeviveId;
+    EjectDeviceInfo m_curEjectDeviceInfo;
 
 public Q_SLOTS:
     void iconActivated(QSystemTrayIcon::ActivationReason reason);    
-    void onConvertShowWindow();
-    void on_Maininterface_hide();
+    void onConvertShowWindow(QString strDriveId, QString strMountUri);
+    void onConvertUpdateWindow(QString strDevName, unsigned uDevType);
+    void onMaininterfacehide();
     void on_clickPanelToHideInterface();
+    void onRequestSendDesktopNotify(QString message, QString strIcon);
+    void onInsertAbnormalDiskNotify(QString message);
+    void onNotifyWnd(QObject* obj, QEvent *event);
+    void onClickedEject(EjectDeviceInfo eDeviceInfo);
+    void onRemountVolume(FDVolumeInfo volumeInfo);
+    void onCheckDriveValid(FDDriveInfo driveInfo);
+
+    bool onDeviceErrored(GDrive* drive);
+    void onMountVolume(GVolume*);
+    void onEjectVolumeForce(GVolume* v);             // A fix pops up if the mount fails
+
 Q_SIGNALS:
     void clicked();
-    void convertShowWindow();
+    void convertShowWindow(QString strDriveId, QString strMountUri);
+    void convertUpdateWindow(QString, unsigned);
     void unloadMount();
+    void telephoneMount();
+
+    bool deviceError(GDrive*);
+    void mountVolume(GVolume*);
+    void ejectVolumeForce(GVolume*);
+    void remountVolume(FDVolumeInfo volumeInfo);
+    void checkDriveValid(FDDriveInfo driveInfo);
 
 protected:
     void resizeEvent(QResizeEvent *event);
-    //void enterEvent(QEvent *event);
     bool eventFilter(QObject *obj, QEvent *event);
-    //void leaveEvent(QEvent *event);
+    void paintEvent(QPaintEvent *event);
+
+private:
+    bool                                mIsrunning = false;
+    QMap<QString, RepairDialogBox*>     mRepairDialog;
 };
 
 #endif
